""" pydantic models for kubernetes job config and container"""
from typing import Literal, Optional
from pydantic import BaseModel


class Container(BaseModel):
    """Container model"""

    name: str
    image: str
    pull_policy: Literal["Never", "Always", "IfNotPresent"]
    config_map: str
    command: list[str]


class JobConfig(BaseModel):
    """Job config model"""

    version: Optional[str] = "batch/v1"
    name: str
    containers: list[Container]
    restart: Literal["Always", "Never"]
    service_account: str
