"""
Pyneers CLI
"""
import os
from pathlib import Path
import sys
import fire
from colorama import Fore, Style
from . import file_dir_creator


class PyneersCLI:
    """
    Pyneers CLI class
    """

    # pylint: disable=R0915
    def init(self, project_name=None):
        """init for test framework repo strucutre setup

        Args:
            project_name (_type_, optional): name of the project directory. Defaults to None.
        """
        greeting_text = f"\n!!!!{Fore.YELLOW}Welcome to Pyneers Setup!!!!{Style.RESET_ALL}\n"
        print(greeting_text)
        present_directory_path = Path.cwd()
        project_name = present_directory_path
        print(f"\n{Fore.GREEN}Project directory created successfully{Style.RESET_ALL}!")

        FileDirUtility_Object = file_dir_creator.FileDirUtility(project_name)

        # Checks if tests directory alreday exists,if it exists name of pyneers tests folder changed to tests_sample.
        test_directory_name = "tests"
        if Path("tests").exists() and Path("tests").is_dir():
            print(f"\n{Fore.GREEN}Creating sample tests in tests_sample folder{Style.RESET_ALL}.")
            test_directory_name = "tests_sample"

        # Creating Directories
        directories = ["src", "deployments", "configs", "helpers", test_directory_name]
        for directory in directories:
            FileDirUtility_Object.directory_maker(directory_name=directory)
        FileDirUtility_Object.directory_maker(directory_name=".github", log_info=False)
        FileDirUtility_Object.directory_maker(directory_name=".github/workflows", log_info=False)

        # Creating Files
        files = {
            "Dockerfile": file_dir_creator.dockerfile_content,
            "conftest.py": file_dir_creator.conftest_content,
            "pytest.ini": file_dir_creator.pytestini_content,
            "README.md": file_dir_creator.readme_content,
            "entrypoint.sh": file_dir_creator.entrypoint_content,
        }

        for file, content in files.items():
            FileDirUtility_Object.file_maker(file_name=file, content=content)
        FileDirUtility_Object.file_maker(
            file_name=".pre-commit-config.yaml",
            log_info=False,
            content=file_dir_creator.pre_commit_content,
        )
        FileDirUtility_Object.file_maker(
            file_name="on-pull-request.yaml",
            path=".github/workflows",
            content=file_dir_creator.workflow_content,
        )
        FileDirUtility_Object.file_maker(
            file_name="config.j2", path="configs", content=file_dir_creator.configsj2_content
        )

        # Copy files from your local 'tests' package to the created 'tests' folder
        source_pyneers_dir = (
            Path(sys.prefix)
            / "lib"
            / f"python{sys.version_info[0]}.{sys.version_info[1]}"
            / "site-packages"
            / "pyneers"
        )
        source_tests_dir = source_pyneers_dir / "examples" / "tests"
        destination_tests_dir = project_name / test_directory_name
        print("Copying sample test files.\n")
        os.system(f"cp -r {source_tests_dir}/* {destination_tests_dir}")

        official_doc = "https://github.com/pages/auth?nonce=cf063190-c9b3-45db-ae22-ddb81da7c78e&page_id=37694601&path=Lw"  # noqa E501
        official_repo = "https://github.com/amagimedia/pyneers"

        print(
            f"{Fore.GREEN}Pyneers project '{project_name}' has been initialized{Style.RESET_ALL}!\n"
        )
        print(
            f"\n{Fore.LIGHTCYAN_EX}More more details visit-\
                \nofficial doc:{official_doc}\
                \nofficial repo:{official_repo} {Style.RESET_ALL}\n"
        )
        print(
            f"\nRun below command now:\
            \n{Fore.BLUE}pytest{Style.RESET_ALL}\
            \nthis should run sample tests\n"
        )


def main():
    """
    main method
    """
    pyneers_cli = PyneersCLI()
    fire.Fire(pyneers_cli)


if __name__ == "__main__":
    main()
