"""
Module for generating test data
"""
import uuid
from faker import Faker


class FakeDataGenerator:
    """
    Class for generating fake data using faker
    https://faker.readthedocs.io/en/master/providers/faker.providers.python.html
    """

    def __init__(self):
        """
        Initiates faker instance
        """
        self.fake = Faker()

    def name(self):
        """
        Generates a random name
        """
        return self.fake.name()

    def description(self):
        """
        Generates a random description
        """
        return self.fake.text()

    def uuid(self):
        """
        Generates a uuid
        """
        return str(uuid.UUID(int=self.fake.random.getrandbits(128)))

    def email(self):
        """
        Generates a random email
        """
        return self.fake.email()

    def password(self):
        """
        Generates a random password
        """
        return self.fake.password()
