"""
    Module consisting of DBUtils class
"""
from pyneers.utils.db.db_mongo import DBUtilsMongo
from pyneers.utils.db.db_sql import DBUtilsSql
from pyneers.utils.logger import CustomLogger

LOG = CustomLogger.getLogger(__name__)


class DBUtils:
    """

    This class, `DBUtils`, is a database utility class that provides methods
    for performing various database operations based on the specified database type.
    It supports PostgreSQL, MySQL and MongoDB databases.

    Attributes:
        db_config (DBConfig): An instance of the DBConfig class containing
        database connection information.
    """

    def __new__(cls, db_config):
        instance = super(DBUtils, cls).__new__(cls)
        instance.db_config = db_config
        instance.db = instance._create_db_instance()
        return instance.db

    def _create_db_instance(self):
        if self.db_config.db_type in ("postgresql", "mysql"):
            return DBUtilsSql(db_config=self.db_config)
        if self.db_config.db_type == "mongodb":
            return DBUtilsMongo(db_config=self.db_config)

        raise ValueError("Unsupported database type")
