""" Controller to determine file type and call handlers"""

from pathlib import Path

from pyneers.utils.csv_handler import CSVHandler
from pyneers.utils.excel_handler import ExcelHandler
from pyneers.utils.json_handler import JSONHandler
from pyneers.utils.text_handler import TextHandler
from pyneers.utils.yaml_handler import YAMLHandler


def FileHandler(filepath: str):
    """FileHandler to take file path and return its corresponding handler

    Args:
        filepath (str): Path of the file on which actions to be performed

    Returns:
        FileHandler: Returns file handler for that specific file type
    """
    path = Path(filepath)
    type = path.suffix[1:].lower()

    if type == "json":
        return JSONHandler(filepath)
    if type == "csv":
        return CSVHandler(filepath)
    if type in ("yaml", "yml"):
        return YAMLHandler(filepath)
    if type in ("xlsx"):
        return ExcelHandler(filepath)

    return TextHandler(filepath)
